import React from 'react';
import { WithYMapsProps } from '../hocs/withYMaps';
import { BaseGeoObjectProps } from './BaseGeoObject';
import { AnyObject, WithInstanceRef } from '../util/typing';
import { IDataManager, IGeometry } from 'yandex-maps';
import { ErrorBoundaryProps } from '../hocs/with-error-boundary';
interface GeoObjectProps extends Omit<BaseGeoObjectProps, 'name'> {
    /**
     * GeoObject [feature.geometry](https://tech.yandex.com/maps/doc/jsapi/2.1/ref/reference/GeoObject-docpage/#param-feature.geometry)
     */
    geometry?: IGeometry[][][][] | number[][] | object;
    /**
     * Uncontrolled GeoObject [feature.geometry](https://tech.yandex.com/maps/doc/jsapi/2.1/ref/reference/GeoObject-docpage/#param-feature.geometry)
     */
    defaultGeometry?: IGeometry[][][][] | number[][] | object;
    /**
     * GeoObject [feature.properties](https://tech.yandex.com/maps/doc/jsapi/2.1/ref/reference/GeoObject-docpage/#param-feature.properties)
     */
    properties?: AnyObject | IDataManager;
    /**
     * Uncontrolled GeoObject [feature.properties](https://tech.yandex.com/maps/doc/jsapi/2.1/ref/reference/GeoObject-docpage/#param-feature.properties)
     */
    defaultProperties?: AnyObject | IDataManager;
    /**
     * GeoObject [options](https://tech.yandex.com/maps/doc/jsapi/2.1/ref/reference/GeoObject-docpage/#param-options)
     */
    options?: AnyObject;
    /**
     * Uncontrolled GeoObject [options](https://tech.yandex.com/maps/doc/jsapi/2.1/ref/reference/GeoObject-docpage/#param-options)
     */
    defaultOptions?: AnyObject;
}
export declare const GeoObject: React.FC<React.PropsWithChildren<GeoObjectProps & WithYMapsProps & WithInstanceRef & ErrorBoundaryProps & AnyObject>>;
declare const _default: React.FC<React.PropsWithChildren<GeoObjectProps & WithYMapsProps & WithInstanceRef & ErrorBoundaryProps & AnyObject>>;
export default _default;
