import React from 'react';
import { WithYMapsProps } from '../hocs/withYMaps';
import { BaseGeoObjectProps } from './BaseGeoObject';
import { IDataManager, ILineStringGeometry, IPolylineOptions } from 'yandex-maps';
import { AnyObject, WithInstanceRef } from '../util/typing';
import { ErrorBoundaryProps } from '../hocs/with-error-boundary';
interface PolylineProps extends Omit<BaseGeoObjectProps, 'name'> {
    /**
     * Polyline [geometry](https://tech.yandex.com/maps/doc/jsapi/2.1/ref/reference/Polyline-docpage/#param-geometry)
     */
    geometry?: number[][] | AnyObject | ILineStringGeometry;
    /**
     * Uncontrolled Polyline [geometry](https://tech.yandex.com/maps/doc/jsapi/2.1/ref/reference/Polyline-docpage/#param-geometry)
     */
    defaultGeometry?: number[][] | AnyObject | ILineStringGeometry;
    /**
     * Polyline [properties](https://tech.yandex.com/maps/doc/jsapi/2.1/ref/reference/Polyline-docpage/#param-properties)
     */
    properties?: AnyObject | IDataManager;
    /**
     * Uncontrolled Polyline [properties](https://tech.yandex.com/maps/doc/jsapi/2.1/ref/reference/Polyline-docpage/#param-properties)
     */
    defaultProperties?: AnyObject | IDataManager;
    /**
     * Polyline [options](https://tech.yandex.com/maps/doc/jsapi/2.1/ref/reference/Polyline-docpage/#param-options)
     */
    options?: IPolylineOptions;
    /**
     * Uncontrolled Polyline [options](https://tech.yandex.com/maps/doc/jsapi/2.1/ref/reference/Polyline-docpage/#param-options)
     */
    defaultOptions?: IPolylineOptions;
}
export declare const Polyline: React.FC<React.PropsWithChildren<PolylineProps & WithYMapsProps & WithInstanceRef & ErrorBoundaryProps & AnyObject>>;
declare const _default: React.FC<React.PropsWithChildren<PolylineProps & WithYMapsProps & WithInstanceRef & ErrorBoundaryProps & AnyObject>>;
export default _default;
